from dataiku.connector import Connector
from airtable import airtable_api
from airtable_common import get_api_key_from_config, RecordsLimit


class AirtableConnector(Connector):

    def __init__(self, config, plugin_config):
        Connector.__init__(self, config, plugin_config)  # pass the parameters to the base class

        self.base = self.config.get("base_select")
        if not self.base or self.base == "_dku_manual_select":
            self.base = self.config.get("base")
        self.table = self.config.get("table_select")
        if not self.table or self.table == "_dku_manual_select":
            self.table = self.config.get("table")
        self.key = get_api_key_from_config(config)
        self.retrieve_id = self.config.get("retrieve_id", "no")

        if self.base is None or self.table is None or self.key is None:
            raise ValueError("Missing parameters (Base ID, or Table name, or API key")

    def get_read_schema(self):
        return None

    def generate_rows(self, dataset_schema=None, dataset_partitioning=None,
                      partition_id=None, records_limit=-1):

        limit = RecordsLimit(records_limit=records_limit)
        looping = True
        offset = None
        params = {
            "pageSize": 100
        }

        while looping:
            if offset is not None:
                params.update({'offset': offset})
            results = airtable_api(self.base, self.table, self.key, parameters=params)
            for record in results.get("records"):
                if self.retrieve_id == 'yes':
                    record["fields"]["id"] = record["id"]
                yield record["fields"]
            offset = results.get("offset")
            looping = False if offset is None else True
            if limit.is_reached():
                return

    def get_writer(self, dataset_schema=None, dataset_partitioning=None,
                   partition_id=None):
        raise Exception("Unimplemented")

    def get_partitioning(self):
        raise Exception("Unimplemented")

    def list_partitions(self, partitioning):
        return []

    def partition_exists(self, partitioning, partition_id):
        raise Exception("unimplemented")

    def get_records_count(self, partitioning=None, partition_id=None):
        raise Exception("unimplemented")
